@@ -24,6 +24,7 @@
 
 #pylint:disable=unused-import,import-outside-toplevel
 #pylint:disable=no-name-in-module,import-error
+import re
 from functools import WRAPPER_ASSIGNMENTS
 import six
 
@@ -69,12 +70,37 @@ except ModuleNotFoundError: #pylint:disable=undefined-variable,bad-except-order
     # <= Django 1.10, Python>=3.6
     from django.core.urlresolvers import NoReverseMatch, reverse, reverse_lazy
 
+try:
+    from django.urls import include, path, re_path
+except ImportError: # <= Django 2.0, Python<3.6
+    from django.conf.urls import include, url as re_path
+
+    def path(route, view, kwargs=None, name=None):
+        re_route = re.sub(
+            r'<slug:([a-z\_]+)>', r'(?P<\1>[a-zA-Z0-9_\-\+\.]+)', route)
+        return re_path(re_route, view, kwargs=kwargs, name=name)
+
+try:
+    if six.PY3:
+        from django.utils.encoding import force_str
+    else:
+        from django.utils.encoding import force_text as force_str
+except ImportError: # django < 3.0
+    from django.utils.encoding import force_text as force_str
+
+
 try:
     from django.utils.module_loading import import_string
 except ImportError: # django < 1.7
     from django.utils.module_loading import import_by_path as import_string
 
 
+try:
+    from django.utils.translation import gettext_lazy
+except ImportError: # django < 3.0
+    from django.utils.translation import ugettext_lazy as gettext_lazy
+
+
 def get_loaders():
     loaders = []
     try:
