@@ -31,11 +31,11 @@ from django.contrib.auth import get_user_model
 from django.db import IntegrityError, models, transaction
 from django.db.models import Max, Q
 from django.template.defaultfilters import slugify
-from django.utils.translation import ugettext_lazy as _
 from rest_framework.exceptions import ValidationError
 
 from . import settings
-from .compat import import_string, python_2_unicode_compatible, six
+from .compat import (gettext_lazy as _, import_string,
+    python_2_unicode_compatible, six)
 
 
 LOGGER = logging.getLogger(__name__)
@@ -185,7 +185,7 @@ class PageElement(models.Model):
         default=datetime.timedelta,  # stored in microseconds
         help_text=_("Reading time of the material (in hh:mm:ss)"))
     lang = models.CharField(_("Language the material is written in"),
-         default=settings.LANGUAGE_CODE, max_length=5)
+         default=settings.LANGUAGE_CODE, max_length=8)
     extra = get_extra_field_class()(null=True, blank=True)
     relationships = models.ManyToManyField("self",
         related_name='related_to', through='RelationShip', symmetrical=False)
@@ -426,57 +426,6 @@ class Vote(models.Model):
         return self.vote == self.DOWN_VOTE
 
 
-@python_2_unicode_compatible
-class MediaTag(models.Model):
-
-    location = models.CharField(max_length=250)
-    tag = models.CharField(max_length=50)
-
-    def __str__(self):
-        return str(self.tag)
-
-
-@python_2_unicode_compatible
-class LessVariable(models.Model):
-    """
-    This model stores value of a variable used to generate a css file.
-    """
-    name = models.CharField(max_length=250)
-    value = models.CharField(max_length=250)
-    created_at = models.DateTimeField(auto_now_add=True)
-    updated_at = models.DateTimeField(auto_now=True)
-    account = models.ForeignKey(settings.ACCOUNT_MODEL,
-        null=True, on_delete=models.SET_NULL,
-        related_name='account_less_variable')
-    cssfile = models.CharField(max_length=50)
-
-    class Meta:
-        unique_together = ('account', 'cssfile', 'name')
-
-    def __str__(self):
-        return '%s: %s' % (self.name, self.value)
-
-
-@python_2_unicode_compatible
-class ThemePackage(models.Model):
-    """
-    This model allow to record uploaded template.
-    """
-    slug = models.SlugField(unique=True)
-    account = models.ForeignKey(
-        settings.ACCOUNT_MODEL, null=True, on_delete=models.CASCADE,
-        related_name='account_template', blank=True)
-    name = models.CharField(max_length=150)
-    created_at = models.DateTimeField(auto_now_add=True)
-    updated_at = models.DateTimeField(auto_now=True)
-    is_active = models.BooleanField(default=False)
-
-    def __str__(self):
-        if self.account:
-            return '%s-%s' % (self.account, self.name)
-        return self.name
-
-
 def build_content_tree(roots=None, prefix=None, cut=None,
                        visibility=None, accounts=None):
     """
@@ -503,6 +452,9 @@ def build_content_tree(roots=None, prefix=None, cut=None,
     # is stored in terms of `PageElement` (node) and `Relationship` (edge).
     # We use a breadth-first search algorithm here such as to minimize
     # the number of queries to the database.
+    LOGGER.debug("build_content_tree"\
+        "(roots=%s, prefix=%s, cut=%s, visibility=%s, accounts=%s)",
+        roots, prefix, cut, visibility, accounts)
     if roots is None:
         roots = PageElement.objects.get_roots(
             visibility=visibility, accounts=accounts).order_by(
@@ -520,8 +472,7 @@ def build_content_tree(roots=None, prefix=None, cut=None,
     # does not end with one).
     if not prefix.startswith("/"):
         prefix = '/%s' % prefix
-    if prefix.endswith("/"):
-        prefix = prefix[:-1]
+    prefix = prefix.rstrip('/')
     filtered_in = None
     if visibility:
         for visible in visibility:
